@@ -96,9 +96,9 @@ runAssembly <- function(config, constraints, xdata = NULL, objective = NULL) {
 
     # add x for previous items
 
-    xmat          <- xdata[['xmat']]
-    xdir          <- xdata[['xdir']]
-    xrhs          <- xdata[['xrhs']]
+    xmat          <- xdata[["xmat"]]
+    xdir          <- xdata[["xdir"]]
+    xrhs          <- xdata[["xrhs"]]
 
     if (!is.null(xmat) && !is.null(xdir) && !is.null(xrhs)) {
       mat <- rbind(mat, xmat)
@@ -125,7 +125,7 @@ runAssembly <- function(config, constraints, xdata = NULL, objective = NULL) {
 
   MIP$solution[types == "B"] <- round(MIP$solution[types == "B"], 0)
 
-  solve_time <- (proc.time() - solve_time)[['elapsed']]
+  solve_time <- (proc.time() - solve_time)[["elapsed"]]
 
 
   # STIMULUS-LEVEL SORT IF NEEDED --------------------------------------------------------------
@@ -181,15 +181,15 @@ runAssembly <- function(config, constraints, xdata = NULL, objective = NULL) {
   if (sort_by_info) {
     shadow_test <- shadow_test[order(shadow_test[["info"]], decreasing = TRUE), ]
   }
-  if (!is.null(constraints@item_order_by)) {
-    shadow_test <- shadow_test[order(shadow_test[[constraints@item_order_by]]), ]
-  }
   if (constraints@set_based) {
     shadow_test <- shadow_test[order(shadow_test[["STID"]]), ]
   }
   if (constraints@set_based & sort_by_info) {
     shadow_test <- shadow_test[order(shadow_test[["meanInfo"]], decreasing = TRUE), ]
   }
+  if (!is.null(constraints@item_order_by)) {
+    shadow_test <- shadow_test[order(shadow_test[[constraints@item_order_by]]), ]
+  }
   if (!is.null(constraints@stim_order_by)) {
     shadow_test <- shadow_test[order(shadow_test[[constraints@stim_order_by]]), ]
   }
@@ -285,9 +285,9 @@ runMIP <- function(solver, obj, mat, dir, rhs, maximize, types,
 isOptimal <- function(status, solver) {
   is_optimal <- FALSE
   if (toupper(solver) == "LPSYMPHONY") {
-    is_optimal <- names(status) %in% c("TM_OPTIMAL_SOLUTION_FOUND", "PREP_OPTIMAL_SOLUTION_FOUND")
+    is_optimal <- names(status) %in% c("TM_OPTIMAL_SOLUTION_FOUND", "PREP_OPTIMAL_SOLUTION_FOUND", "TM_TARGET_GAP_ACHIEVED")
   } else if (toupper(solver) == "RSYMPHONY") {
-    is_optimal <- names(status) %in% c("TM_OPTIMAL_SOLUTION_FOUND", "PREP_OPTIMAL_SOLUTION_FOUND")
+    is_optimal <- names(status) %in% c("TM_OPTIMAL_SOLUTION_FOUND", "PREP_OPTIMAL_SOLUTION_FOUND", "TM_TARGET_GAP_ACHIEVED")
   } else if (toupper(solver) == "GUROBI") {
     is_optimal <- status %in% c("OPTIMAL")
   } else if (toupper(solver) == "LPSOLVE") {
